DATASETS = {
    "crd": "Completely randomized design – single factor",
    "rcbd": "Randomized complete block design",
    "factorial": "Two-factor factorial experiment",
    "splitplot": "Split plot design",
    "mixed": "Mixed model example",
    "gxe": "Multi-environment trial",
    "grouped": "Grouped analysis example",
    "multitrait": "Multi-response trait dataset"
}
